import React, { useCallback, memo } from "react";
import HeaderCell from "./HeaderCell";
import { assertIsValidKey } from "./utils";
import SuperHeaderCell from "./SuperHeaderCell";
function HeaderRow({ columns, superHeader, rows, rowKey, onSelectedRowsChange, allRowsSelected, onColumnResize, sortColumn, sortDirection, onSort, }) {
    const handleAllRowsSelectionChange = useCallback((checked) => {
        if (!onSelectedRowsChange)
            return;
        assertIsValidKey(rowKey);
        const newSelectedRows = new Set();
        if (checked) {
            for (const row of rows) {
                newSelectedRows.add(row[rowKey]);
            }
        }
        onSelectedRowsChange(newSelectedRows);
    }, [onSelectedRowsChange, rows, rowKey]);
    if (superHeader == undefined || superHeader.length == 0) {
        return (React.createElement("div", { role: "row", "aria-rowindex": 1, className: "rdg-header-row" }, columns.map((column) => {
            return (React.createElement(HeaderCell, { key: column.key, column: column, onResize: onColumnResize, allRowsSelected: allRowsSelected, onAllRowsSelectionChange: handleAllRowsSelectionChange, onSort: onSort, sortColumn: sortColumn, sortDirection: sortDirection }));
        })));
    }
    else {
        return (React.createElement("div", null, superHeader.map((header) => (React.createElement("div", { role: "superHeader", "aria-rowindex": 1, className: "rdg-header-row" }, header.map((subHeader, i, arr) => {
            var prevWidth;
            if (i > 0) {
                prevWidth = arr[i - 1].span;
            }
            else {
                prevWidth = arr[i].span;
            }
            return (React.createElement(SuperHeaderCell, { key: subHeader.name, prevWidth: prevWidth * columns[0].width, column: columns[0], index: i, superSpecs: subHeader, onResize: onColumnResize, allRowsSelected: allRowsSelected, onAllRowsSelectionChange: handleAllRowsSelectionChange, onSort: onSort, sortColumn: sortColumn, sortDirection: sortDirection }));
        }))))));
    }
}
export default memo(HeaderRow);
//# sourceMappingURL=HeaderRow.js.map